These files represent the bundled `Isso`_ JavaScript
client. The Isso client is bundled to reduce installation effort. They are
built from on a modified branch:
https://github.com/sprin/isso/tree/pg-discuss

.. _Isso: http://posativ.org/isso/
